You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [12/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/in...

Modified: openoffice/trunk/main/unotools/source/config/configitem.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/configitem.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/configitem.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/configitem.cxx Tue Apr 29 19:25:03 2014
@@ -496,7 +496,7 @@ Sequence< sal_Bool > ConfigItem::GetRead
     sal_Int32 nCount = rNames.getLength();
     Sequence< sal_Bool > lStates(nCount);
 
-    // We must be shure to return a valid information everytime!
+    // We must be shure to return a valid information every time!
     // Set default to non readonly ... similar to the configuration handling of this property.
     for ( i=0; i<nCount; ++i)
         lStates[i] = sal_False;
@@ -1165,7 +1165,7 @@ sal_Bool ConfigItem::ReplaceSetPropertie
                         {
                             // #i37322#: fallback action: replace with <void/>
                             xCont->replaceByName(pContainerSubNodes[nContSub], Any());
-                            // fallback successfull: continue looping
+                            // fallback successful: continue looping
                             continue;
                         }
                         catch (Exception &)

Modified: openoffice/trunk/main/unotools/source/config/configmgr.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/configmgr.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/configmgr.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/configmgr.cxx Tue Apr 29 19:25:03 2014
@@ -266,7 +266,7 @@ Reference< XHierarchicalNameAccess> Conf
     pArgs[1] <<= aUpdate;
 
     // Initialize item with support for reading/writing more then one locales at same time!
-	// It's neccessary for creation of a complete configuration entry without changing office locale
+	// It's necessary for creation of a complete configuration entry without changing office locale
 	// at runtime.
     if((rCfgItem.GetMode() & CONFIG_MODE_ALL_LOCALES) == CONFIG_MODE_ALL_LOCALES)
 	{

Modified: openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx Tue Apr 29 19:25:03 2014
@@ -122,7 +122,7 @@ class SvtDynMenu
     public:
         //---------------------------------------------------------------------------------------------------------
         // append setup written menu entry
-        // Don't touch name of entry. It was defined by setup and must be the same everytime!
+        // Don't touch name of entry. It was defined by setup and must be the same every time!
         // Look for double menu entries here too ... may be some seperator items are supeflous ...
         void AppendSetupEntry( const SvtDynMenuEntry& rEntry )
         {
@@ -163,7 +163,7 @@ class SvtDynMenu
 
         //---------------------------------------------------------------------------------------------------------
         // convert internal list to external format
-        // for using it on right menus realy
+        // for using it on right menus really
         // Notice:   We build a property list with 4 entries and set it on result list then.
         //           The while-loop starts with pointer on internal member list lSetupEntries, change to
         //           lUserEntries then and stop after that with NULL!
@@ -410,7 +410,7 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMe
     :   ConfigItem( ROOTNODE_MENUS )
 	// Init member then...
 {
-    // Get names and values of all accessable menu entries and fill internal structures.
+    // Get names and values of all accessible menu entries and fill internal structures.
 	// See impl_GetPropertyNames() for further informations.
     sal_uInt32              nNewCount           = 0;
     sal_uInt32              nWizardCount        = 0;
@@ -453,8 +453,8 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMe
     OUString    sName         ;
 
     // We must use these one instance object(!) to get information about installed modules.
-    // These information are used to filter menu entries wich need not installed modules ...
-    // Such entries shouldnt be available then!
+    // These information are used to filter menu entries which need not installed modules ...
+    // Such entries shouldn't be available then!
     // see impl_IsEntrySupported() too
     SvtModuleOptions aModuleOptions;
 

Modified: openoffice/trunk/main/unotools/source/config/eventcfg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/eventcfg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/eventcfg.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/eventcfg.cxx Tue Apr 29 19:25:03 2014
@@ -331,7 +331,7 @@ sal_Bool SAL_CALL GlobalEventConfig_Impl
 
 Type SAL_CALL GlobalEventConfig_Impl::getElementType(  ) throw (RuntimeException)
 {
-    //DF definitly not sure about this??
+    //DF definitely not sure about this??
     return ::getCppuType((const Sequence<beans::PropertyValue>*)0);
 }
 

Modified: openoffice/trunk/main/unotools/source/config/fontcfg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/fontcfg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/fontcfg.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/fontcfg.cxx Tue Apr 29 19:25:03 2014
@@ -106,7 +106,7 @@ DefaultFontConfiguration::DefaultFontCon
     {
         // get service provider
         Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
-        // create configuration hierachical access name
+        // create configuration hierarchical access name
         if( xSMgr.is() )
         {
             try
@@ -386,7 +386,7 @@ FontSubstConfiguration::FontSubstConfigu
     {
         // get service provider
         Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
-        // create configuration hierachical access name
+        // create configuration hierarchical access name
         if( xSMgr.is() )
         {
             try

Modified: openoffice/trunk/main/unotools/source/config/itemholder1.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/itemholder1.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/itemholder1.hxx (original)
+++ openoffice/trunk/main/unotools/source/config/itemholder1.hxx Tue Apr 29 19:25:03 2014
@@ -35,7 +35,7 @@
 // namespaces
 
 #ifdef css
-#error "Cant use css as namespace alias."
+#error "Can't use css as namespace alias."
 #else
 #define css ::com::sun::star
 #endif

Modified: openoffice/trunk/main/unotools/source/config/lingucfg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/lingucfg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/lingucfg.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/lingucfg.cxx Tue Apr 29 19:25:03 2014
@@ -1134,7 +1134,7 @@ sal_Bool SvtLinguConfig::GetDictionaryEn
         DBG_ASSERT( aFormatName.getLength(), "Dictionary format name not set" );
         DBG_ASSERT( aLocaleNames.getLength(), "No locales set for the dictionary" );
 
-        // if sucessful continue
+        // if successful continue
         if (bSuccess)
         {
             // get file URL's for the locations

Modified: openoffice/trunk/main/unotools/source/config/moduleoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/moduleoptions.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/moduleoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/moduleoptions.cxx Tue Apr 29 19:25:03 2014
@@ -63,11 +63,11 @@ namespace css = ::com::sun::star;
 //_________________________________________________________________________________________________________________
 
 /*-************************************************************************************************************//**
-    @descr          These values are used to define neccessary keys from our configuration management to support
+    @descr          These values are used to define necessary keys from our configuration management to support
                     all functionality of these implementation.
 					It's a fast way to make changes if some keys change his name or location!
 
-                    Property handle are neccessary to specify right position in return list of configuration
+                    Property handle are necessary to specify right position in return list of configuration
 					for asked values. We ask it with a list of properties to get his values. The returned list
                     has the same order like our given name list!
                     e.g.:
@@ -147,7 +147,7 @@ struct FactoryInfo
         //---------------------------------------------------------------------------------------------------------
         // returns list of properties, which has changed only!
         // We use given value of sNodeBase to build full qualified pathes ...
-        // Last sign of it must be "/". Beacuse we use it directly, without any additional things!
+        // Last sign of it must be "/". Because we use it directly, without any additional things!
         css::uno::Sequence< css::beans::PropertyValue > getChangedProperties( const ::rtl::OUString& sNodeBase )
         {
             // a) reserve memory for max. count of changed properties
@@ -443,7 +443,7 @@ class SvtModuleOptions_Impl : public ::u
 
 /*-************************************************************************************************************//**
     @short      default ctor
-    @descr      We open our configuration here and read all neccessary values from it.
+    @descr      We open our configuration here and read all necessary values from it.
                 These values are cached till everyone call Commit(). Then we write changed ones back to cfg.
 
     @seealso    baseclass ConfigItem
@@ -460,7 +460,7 @@ SvtModuleOptions_Impl::SvtModuleOptions_
     ,   m_bReadOnlyStatesWellKnown( sal_False )
     ,   m_pOutsideClass( pOutsideClass )
 {
-    // First initialize list of factory infos! Otherwise we couldnt gurantee right working of these class.
+    // First initialize list of factory infos! Otherwise we couldnt guarantee right working of these class.
     for( sal_Int32 nFactory=0; nFactory<FACTORYCOUNT; ++nFactory )
         m_lFactories[nFactory].free();
 
@@ -470,7 +470,7 @@ SvtModuleOptions_Impl::SvtModuleOptions_
     impl_Read( lFactories );
 
     // Enable notification for changes by using configuration directly.
-    // So we can update our internal values immediatly.
+    // So we can update our internal values immediately.
     EnableNotification( lFactories );
 }
 
@@ -541,7 +541,7 @@ void SvtModuleOptions_Impl::Notify( cons
 void SvtModuleOptions_Impl::Commit()
 {
     // Reserve memory for ALL possible factory properties!
-    // Step over all factories and get her realy changed values only.
+    // Step over all factories and get her really changed values only.
     // Build list of these ones and use it for commit.
     css::uno::Sequence< css::beans::PropertyValue > lCommitProperties( FACTORYCOUNT*PROPERTYCOUNT );
     FactoryInfo*                                    pInfo            = NULL                        ;
@@ -862,7 +862,7 @@ void SvtModuleOptions_Impl::SetFactoryDe
 /*-************************************************************************************************************//**
     @short      return list of key names of ouer configuration management which represent our module tree
     @descr      You give use a list of current existing set node names .. and we expand it for all
-                well known properties which are neccessary for this implementation.
+                well known properties which are necessary for this implementation.
                 These full expanded list should be used to get values of this properties.
 
     @seealso    ctor

Modified: openoffice/trunk/main/unotools/source/config/pathoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/pathoptions.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/pathoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/pathoptions.cxx Tue Apr 29 19:25:03 2014
@@ -397,7 +397,7 @@ OUString SvtPathOptions_Impl::SubstVar( 
 	// Convert the returned path to system path!
 	sal_Bool bConvertLocal = sal_False;
 
-	// Search for first occure of "$(...".
+	// Search for first occur of "$(...".
 	sal_Int32 nPosition	= aWorkText.indexOf( SIGN_STARTVARIABLE );	// = first position of "$(" in string
 	sal_Int32 nLength	= 0;										// = count of letters from "$(" to ")" in string
 
@@ -477,7 +477,7 @@ SvtPathOptions_Impl::SvtPathOptions_Impl
 												UNO_QUERY );
     if ( !m_xPathSettings.is() )
 	{
-        // #112719#: check for existance
+        // #112719#: check for existence
 		DBG_ERROR( "SvtPathOptions_Impl::SvtPathOptions_Impl(): #112719# happened again!" );
         throw RuntimeException(
             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Service com.sun.star.util.PathSettings cannot be created" )),

Modified: openoffice/trunk/main/unotools/source/config/viewoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/viewoptions.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/viewoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/viewoptions.cxx Tue Apr 29 19:25:03 2014
@@ -122,15 +122,15 @@ sal_Int32                    SvtViewOpti
 /*-************************************************************************************************************//**
     @descr  declare one configuration item
             These struct hold information about one view item. But not all member are used for all entries!
-            User must decide which information are usefull and which not. We are a container iztem only and doesnt
+            User must decide which information are useful and which not. We are a container iztem only and doesn't
             know anything about the context.
             But; we support a feature:
-                decision between items with default values (should not realy exist in configuration!)
-                and items with real values - changed by user. So user can suppress saving of realy unused items
+                decision between items with default values (should not really exist in configuration!)
+                and items with real values - changed by user. So user can suppress saving of really unused items
                 to disk - because; defaulted items could be restored on runtime without reading from disk!!!
                 And if only items with valid information was written to cfg - we mustn't read so much and save time.
             So we start with an member m_bDefault=True and reset it to False after first set-call.
-            Deficiencies of these solution - we cant allow direct read/write access to our member. We must
+            Deficiencies of these solution - we can't allow direct read/write access to our member. We must
             support it by set/get-methods ...
 *//*-*************************************************************************************************************/
 class IMPL_TViewData
@@ -277,7 +277,7 @@ typedef ::std::hash_map< ::rtl::OUString
     @descr          Implement base data container for view options elements.
                     Every item support ALL possible configuration informations.
                     But not every superclass should use them! Because some view types don't
-                    have it realy.
+                    have it really.
 
     @attention      We implement a write-througt-cache! We use it for reading - but write all changes directly to
                     configuration. (changes are made on internal cache too!). So it's easier to distinguish
@@ -377,8 +377,8 @@ SvtViewOptionsBase_Impl::SvtViewOptionsB
     @short          dtor
     @descr          clean up something
 
-    @attention      We implement a write through cache! So we mustn't do it realy. All changes was written to cfg directly.
-                    Commit isn't neccessary then.
+    @attention      We implement a write through cache! So we mustn't do it really. All changes was written to cfg directly.
+                    Commit isn't necessary then.
 
     @seealso        baseclass ::utl::ConfigItem
     @seealso        method IsModified()
@@ -394,7 +394,7 @@ SvtViewOptionsBase_Impl::~SvtViewOptions
 {
     // dont flush configuration changes here to m_xRoot.
     // That must be done inside every SetXXX() method already !
-    // Here its to late - DisposedExceptions from used configuration access can occure otherwise.
+    // Here its to late - DisposedExceptions from used configuration access can occur otherwise.
 
     m_xRoot.clear();
     m_xSet.clear();

Modified: openoffice/trunk/main/unotools/source/misc/sharedunocomponent.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/misc/sharedunocomponent.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/misc/sharedunocomponent.cxx (original)
+++ openoffice/trunk/main/unotools/source/misc/sharedunocomponent.cxx Tue Apr 29 19:25:03 2014
@@ -202,7 +202,7 @@ namespace utl
 
         // this should be unreachable: As long as we're a CloseListener, we veto the closing. If we're going
         // to close the component ourself, then we revoke ourself as listener *before* the close call. So,
-        // if this here fires, something went definately wrong.
+        // if this here fires, something went definitely wrong.
         DBG_ERROR( "CloseableComponentImpl::notifyClosing: unreachable!" );
     }
 

Modified: openoffice/trunk/main/unoxml/source/dom/element.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unoxml/source/dom/element.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unoxml/source/dom/element.cxx (original)
+++ openoffice/trunk/main/unoxml/source/dom/element.cxx Tue Apr 29 19:25:03 2014
@@ -218,7 +218,7 @@ namespace DOM
                 /* this is not relly allowed by the DOM spec, but this
                    implementation has evidently supported it (by special case
                    handling, so the attribute does not actually become a child)
-                   so allow it for backward compatiblity */
+                   so allow it for backward compatibility */
                 return true;
             default:
                 return false;

Modified: openoffice/trunk/main/unoxml/source/rdf/librdf_repository.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unoxml/source/rdf/librdf_repository.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/unoxml/source/rdf/librdf_repository.cxx (original)
+++ openoffice/trunk/main/unoxml/source/rdf/librdf_repository.cxx Tue Apr 29 19:25:03 2014
@@ -433,7 +433,7 @@ private:
     //     storage they point into, so we keep the repository alive here
     // also, sequence is important: the stream must be destroyed first.
     ::rtl::Reference< librdf_Repository > m_xRep;
-    // needed for synchronizing access to librdf (it doesnt do win32 threading)
+    // needed for synchronizing access to librdf (it doesn't do win32 threading)
     ::osl::Mutex & m_rMutex;
     // the query (in case this is a result of a graph query)
     // not that the redland documentation spells this out explicity, but
@@ -541,7 +541,7 @@ private:
     //     storage they point into, so we keep the repository alive here
     // also, sequence is important: the stream must be destroyed first.
     ::rtl::Reference< librdf_Repository > m_xRep;
-    // needed for synchronizing access to librdf (it doesnt do win32 threading)
+    // needed for synchronizing access to librdf (it doesn't do win32 threading)
     ::osl::Mutex & m_rMutex;
     // not that the redland documentation spells this out explicity, but
     // queries must be freed only after all the results are completely read

Modified: openoffice/trunk/main/uui/source/fltdlg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/uui/source/fltdlg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/uui/source/iahndl-filter.cxx (original)
+++ openoffice/trunk/main/uui/source/iahndl-filter.cxx Tue Apr 29 19:25:03 2014
@@ -96,7 +96,7 @@ handleNoSuchFilterRequest_(
     uno::Reference< document::XInteractionFilterSelect > xFilterTransport;
     getContinuations(rContinuations, &xAbort, &xFilterTransport);
 
-    // check neccessary ressources - if they don't exist - abort or
+    // check necessary ressources - if they don't exist - abort or
     // break this operation
     if (!xAbort.is())
         return;

Modified: openoffice/trunk/main/vbahelper/inc/vbahelper/collectionbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vbahelper/inc/vbahelper/collectionbase.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vbahelper/inc/vbahelper/collectionbase.hxx (original)
+++ openoffice/trunk/main/vbahelper/inc/vbahelper/collectionbase.hxx Tue Apr 29 19:25:03 2014
@@ -61,7 +61,7 @@ public:
         /** Container elements will be converted to VBA items on demand.
 
             The initial container contains intermediate objects (e.g. UNO
-            objects) which will be converted to VBA items everytime the item is
+            objects) which will be converted to VBA items every time the item is
             accessed (e.g. item access method, enumeration). Changes in the
             initial container are reflected by the collection.
          */

Modified: openoffice/trunk/main/vbahelper/inc/vbahelper/vbaeventshelperbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vbahelper/inc/vbahelper/vbaeventshelperbase.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vbahelper/inc/vbahelper/vbaeventshelperbase.hxx (original)
+++ openoffice/trunk/main/vbahelper/inc/vbahelper/vbaeventshelperbase.hxx Tue Apr 29 19:25:03 2014
@@ -130,7 +130,7 @@ protected:
         const css::uno::Sequence< css::uno::Any >& rArgs ) throw (css::lang::IllegalArgumentException) = 0;
 
     /** Derived classes may do additional postprocessing. Called even if the
-        event handler does not exist, or if an error occured during execution. */
+        event handler does not exist, or if an error occurred during execution. */
     virtual void implPostProcessEvent(
         EventQueue& rEventQueue,
         const EventHandlerInfo& rInfo,

Modified: openoffice/trunk/main/vbahelper/source/msforms/vbacontrol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vbahelper/source/msforms/vbacontrol.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vbahelper/source/msforms/vbacontrol.cxx (original)
+++ openoffice/trunk/main/vbahelper/source/msforms/vbacontrol.cxx Tue Apr 29 19:25:03 2014
@@ -271,7 +271,7 @@ ScVbaControl::getControlSource() throw (
 {
 // #FIXME I *hate* having these upstream differences
 // but this is necessary until I manage to upstream other
-// dependant parts
+// dependent parts
 #ifdef VBA_OOBUILD_HACK
 	rtl::OUString sControlSource;
 	uno::Reference< form::binding::XBindableValue > xBindable( m_xProps, uno::UNO_QUERY );

Modified: openoffice/trunk/main/vbahelper/source/vbahelper/collectionbase.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vbahelper/source/vbahelper/collectionbase.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vbahelper/source/vbahelper/collectionbase.cxx (original)
+++ openoffice/trunk/main/vbahelper/source/vbahelper/collectionbase.cxx Tue Apr 29 19:25:03 2014
@@ -117,7 +117,7 @@ SequenceToContainer::SequenceToContainer
         uno::Reference< container::XNamed > xNamed = *aIt;
         *pElementName = xNamed->getName();
         maElements.push_back( uno::Any( xNamed ) );
-        // same name may occur multiple times, VBA returns first occurance
+        // same name may occur multiple times, VBA returns first occurrence
         if( maElementMap.count( *pElementName ) == 0 )
             maElementMap[ *pElementName ] <<= xNamed;
     }
@@ -133,7 +133,7 @@ SequenceToContainer::SequenceToContainer
     {
         *pElementName = aIt->Name;
         maElements.push_back( aIt->Value );
-        // same name may occur multiple times, VBA returns first occurance
+        // same name may occur multiple times, VBA returns first occurrence
         if( maElementMap.count( *pElementName ) == 0 )
             maElementMap[ *pElementName ] = aIt->Value;
     }

Modified: openoffice/trunk/main/vcl/aqua/source/gdi/atsfonts.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/aqua/source/gdi/atsfonts.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/aqua/source/gdi/atsfonts.cxx (original)
+++ openoffice/trunk/main/vcl/aqua/source/gdi/atsfonts.cxx Tue Apr 29 19:25:03 2014
@@ -393,7 +393,7 @@ static bool GetDevFontAttributes( ATSUFo
 			continue;
 
 		// heuristic to find the most common font name
-		// prefering default language names or even better the names matching to the UI language
+		// preferring default language names or even better the names matching to the UI language
 		int nNameValue = (eFontNameLanguage==eUILangCode) ? 0 : ((eFontNameLanguage==0) ? -10 : -20);
 		rtl_TextEncoding eEncoding = RTL_TEXTENCODING_UNICODE;
 		const int nPlatformEncoding = ((int)eFontNamePlatform << 8) + (int)eFontNameScript;

Modified: openoffice/trunk/main/vcl/aqua/source/gdi/salprn.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/aqua/source/gdi/salprn.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/aqua/source/gdi/salprn.cxx (original)
+++ openoffice/trunk/main/vcl/aqua/source/gdi/salprn.cxx Tue Apr 29 19:25:03 2014
@@ -312,7 +312,7 @@ static bool getUseNativeDialog()
     {
         // get service provider
         uno::Reference< XMultiServiceFactory > xSMgr( unohelper::GetMultiServiceFactory() );
-        // create configuration hierachical access name
+        // create configuration hierarchical access name
         if( xSMgr.is() )
         {
             try

Modified: openoffice/trunk/main/vcl/aqua/source/window/salframeview.mm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/aqua/source/window/salframeview.mm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/aqua/source/window/salframeview.mm (original)
+++ openoffice/trunk/main/vcl/aqua/source/window/salframeview.mm Tue Apr 29 19:25:03 2014
@@ -489,7 +489,7 @@ static AquaSalFrame* getMouseContainerFr
 }
 
 // helper class similar to a vos::OGuard for the SalYieldMutex
-// the difference is that it only does tryToAcquire instead of aquire
+// the difference is that it only does tryToAcquire instead of acquire
 // so dreaded deadlocks like #i93512# are prevented
 class TryGuard
 {

Modified: openoffice/trunk/main/vcl/inc/aqua/saldata.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/aqua/saldata.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/aqua/saldata.hxx (original)
+++ openoffice/trunk/main/vcl/inc/aqua/saldata.hxx Tue Apr 29 19:25:03 2014
@@ -84,7 +84,7 @@ struct SalData
 	SALTIMERPROC                                  mpTimerProc;		// timer callback proc
 	AquaSalInstance                              *mpFirstInstance;	// pointer of first instance
 	std::list<AquaSalFrame*>                      maFrames;	        // list of all frames
-    std::hash_set<const AquaSalFrame*,FrameHash>  maFrameCheck;     // for fast check of frame existance
+    std::hash_set<const AquaSalFrame*,FrameHash>  maFrameCheck;     // for fast check of frame existence
 	std::list<AquaSalFrame*>                      maPresentationFrames;  // list of frames in presentation mode
 	SalObject                                    *mpFirstObject;	// pointer of first object window
 	SalVirtualDevice                             *mpFirstVD;    	// first VirDev

Modified: openoffice/trunk/main/vcl/inc/aqua/salgdi.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/aqua/salgdi.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/aqua/salgdi.h (original)
+++ openoffice/trunk/main/vcl/inc/aqua/salgdi.h Tue Apr 29 19:25:03 2014
@@ -344,7 +344,7 @@ public:
     virtual bool			AddTempDevFont( ImplDevFontList*, const String& rFileURL, const String& rFontName );
     // CreateFontSubset: a method to get a subset of glyhps of a font
     // inside a new valid font file
-    // returns TRUE if creation of subset was successfull
+    // returns TRUE if creation of subset was successful
     // parameters: rToFile: contains a osl file URL to write the subset to
     //             pFont: describes from which font to create a subset
     //             pGlyphIDs: the glyph ids to be extracted

Modified: openoffice/trunk/main/vcl/inc/aqua/salmathutils.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/aqua/salmathutils.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/aqua/salmathutils.hxx (original)
+++ openoffice/trunk/main/vcl/inc/aqua/salmathutils.hxx Tue Apr 29 19:25:03 2014
@@ -34,7 +34,7 @@ extern "C" {
 //
 // ------------------------------------------------------------------
 
-// LRectCoor is an abreviation for rectangular coordinates
+// LRectCoor is an abbreviation for rectangular coordinates
 // represented as long integers
 
 struct LRectCoor
@@ -50,7 +50,7 @@ struct LRectCoor
 //
 // ------------------------------------------------------------------
 
-// LRectCoorVec is an abreviation for vectors in rectangular 
+// LRectCoorVec is an abbreviation for vectors in rectangular 
 // coordinates represented as long integers
 
 typedef struct LRectCoor   LRectCoor;

Modified: openoffice/trunk/main/vcl/inc/graphite_cache.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/graphite_cache.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/graphite_cache.hxx (original)
+++ openoffice/trunk/main/vcl/inc/graphite_cache.hxx Tue Apr 29 19:25:03 2014
@@ -183,7 +183,7 @@ public:
     else
     {
       // the pointers aren't the same, but we might still have the same text in a segment
-      // this is expecially needed when editing a large paragraph
+      // this is especially needed when editing a large paragraph
       // each edit changes the pointers, but if we don't reuse any segments it gets very
       // slow.
       rtl::OUString * rope = new rtl::OUString(layoutArgs.mpStr + layoutArgs.mnMinCharPos,

Modified: openoffice/trunk/main/vcl/inc/jobset.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/jobset.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/jobset.h (original)
+++ openoffice/trunk/main/vcl/inc/jobset.h Tue Apr 29 19:25:03 2014
@@ -49,7 +49,7 @@
 struct ImplJobSetup
 {
 	sal_uInt16			mnRefCount; 		// RefCount (only independ data)
-	sal_uInt16			mnSystem;			// Sytem - JOBSETUP_SYSTEM_xxxx
+	sal_uInt16			mnSystem;			// System - JOBSETUP_SYSTEM_xxxx
 	String			maPrinterName;		// Printer-Name
 	String			maDriver;			// Driver-Name
 	Orientation 	meOrientation;		// Orientation

Modified: openoffice/trunk/main/vcl/inc/os2/salgdi.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/os2/salgdi.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/os2/salgdi.h (original)
+++ openoffice/trunk/main/vcl/inc/os2/salgdi.h Tue Apr 29 19:25:03 2014
@@ -230,7 +230,7 @@ protected:
     virtual bool		drawAlphaRect( long nX, long nY, long nWidth, long nHeight, sal_uInt8 nTransparency );
 
 public:
-    // public SalGraphics methods, the interface to teh independent vcl part
+    // public SalGraphics methods, the interface to the independent vcl part
 
     // get device resolution
     virtual void			GetResolution( sal_Int32& rDPIX, sal_Int32& rDPIY );
@@ -276,7 +276,7 @@ public:
     virtual bool			AddTempDevFont( ImplDevFontList*, const String& rFileURL, const String& rFontName );
     // CreateFontSubset: a method to get a subset of glyhps of a font
     // inside a new valid font file
-    // returns TRUE if creation of subset was successfull
+    // returns TRUE if creation of subset was successful
     // parameters: rToFile: contains a osl file URL to write the subset to
     //             pFont: describes from which font to create a subset
     //             pGlyphIDs: the glyph ids to be extracted

Modified: openoffice/trunk/main/vcl/inc/printerjob.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/printerjob.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/printerjob.hxx (original)
+++ openoffice/trunk/main/vcl/inc/printerjob.hxx Tue Apr 29 19:25:03 2014
@@ -111,7 +111,7 @@ public:
      *  to named file.
      *  nMode: only meaningful when saving to file: if nonzero, try
      *  to impose the mode on the resulting file's inode; for nonexistant
-     *  files use open, for existant files try a chmod
+     *  files use open, for existent files try a chmod
      *  rJobName: text to appear in the %%Title comment
      *  rAppName: text to appear in the %%Creator comment
      *  rSetupData: JobData that apply to this job

Modified: openoffice/trunk/main/vcl/inc/salgdi.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/salgdi.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/salgdi.hxx (original)
+++ openoffice/trunk/main/vcl/inc/salgdi.hxx Tue Apr 29 19:25:03 2014
@@ -253,7 +253,7 @@ public:
     virtual bool			AddTempDevFont( ImplDevFontList*, const String& rFileURL, const String& rFontName ) = 0;
     // CreateFontSubset: a method to get a subset of glyhps of a font
     // inside a new valid font file
-    // returns sal_True if creation of subset was successfull
+    // returns sal_True if creation of subset was successful
     // parameters: rToFile: contains a osl file URL to write the subset to
     //             pFont: describes from which font to create a subset
     //             pGlyphIDs: the glyph ids to be extracted

Modified: openoffice/trunk/main/vcl/inc/salwtype.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/salwtype.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/salwtype.hxx (original)
+++ openoffice/trunk/main/vcl/inc/salwtype.hxx Tue Apr 29 19:25:03 2014
@@ -233,7 +233,7 @@ struct SalInputContextChangeEvent
 struct SalSurroundingTextRequestEvent
 {
     UniString       maText;         // Text
-    sal_uLong           mnStart;        // The beggining index of selected range
+    sal_uLong           mnStart;        // The beginning index of selected range
     sal_uLong           mnEnd;          // The end index of selected range
 };
 
@@ -244,7 +244,7 @@ struct SalSurroundingTextRequestEvent
 // SURROUNDINGTEXTSELECTIONCHANGE
 struct SalSurroundingTextSelectionChangeEvent
 {
-    sal_uLong           mnStart;        // The beggining index of selected range
+    sal_uLong           mnStart;        // The beginning index of selected range
     sal_uLong           mnEnd;          // The end index of selected range
 };
 

Modified: openoffice/trunk/main/vcl/inc/unx/XIM.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/unx/XIM.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/unx/XIM.h (original)
+++ openoffice/trunk/main/vcl/inc/unx/XIM.h Tue Apr 29 19:25:03 2014
@@ -48,7 +48,7 @@ typedef struct _XIMAnnotation {
 } XIMAnnotation;
 
 /*
-  XIMUText: XIMText extention for UTF16
+  XIMUText: XIMText extension for UTF16
  */
 typedef struct _XIMUnicodeText {
   unsigned short length;

Modified: openoffice/trunk/main/vcl/inc/unx/wmadaptor.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/unx/wmadaptor.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/unx/wmadaptor.hxx (original)
+++ openoffice/trunk/main/vcl/inc/unx/wmadaptor.hxx Tue Apr 29 19:25:03 2014
@@ -213,7 +213,7 @@ public:
     { return m_aWMWorkAreas[n]; }
     
     /*
-     * attemp to switch the desktop to a certain workarea
+     * attempt to switch the desktop to a certain workarea
      * if bConsiderWM is true, then on some WMs the call will not result in any action
      */
     void switchToWorkArea( int nWorkArea, bool bConsiderWM = true ) const;

Modified: openoffice/trunk/main/vcl/inc/vcl/lazydelete.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/lazydelete.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/lazydelete.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/lazydelete.hxx Tue Apr 29 19:25:03 2014
@@ -123,7 +123,7 @@ namespace vcl
         typedef std::hash_map< sal_IntPtr, unsigned int > PtrToIndexMap;
         PtrToIndexMap                       m_aPtrToIndex;
         
-        /** strict weak ordering funtion to bring objects to be destroyed lazily
+        /** strict weak ordering function to bring objects to be destroyed lazily
         in correct order, e.g. for Window objects children before parents
         */
         static bool is_less( T* left, T* right );
@@ -204,7 +204,7 @@ namespace vcl
     /*
     class DeleteOnDeinit matches a similar need as LazyDelete for static objects:
     you may not access vcl objects after DeInitVCL has been called this includes their destruction
-    therefore disallowing the existance of static vcl object like e.g. a static BitmapEx
+    therefore disallowing the existence of static vcl object like e.g. a static BitmapEx
     To work around this use DeleteOnDeinit<BitmapEx> which will allow you to have a static object container,
     that will have its contents destroyed on DeinitVCL. The single drawback is that you need to check on the
     container object whether it still contains content before actually accessing it.
@@ -251,7 +251,7 @@ namespace vcl
         T* get() { return m_pT; }
         
         // set contents, returning old contents
-        // ownership is transfered !
+        // ownership is transferred !
         T* set( T* i_pNew ) { T* pOld = m_pT; m_pT = i_pNew; return pOld; }
     };
 

Modified: openoffice/trunk/main/vcl/inc/vcl/pdfwriter.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/pdfwriter.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/pdfwriter.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/pdfwriter.hxx Tue Apr 29 19:25:03 2014
@@ -204,7 +204,7 @@ public:
         // PDF/A does not allow transparency
         Warning_Transparency_Omitted_PDFA,
 
-        // transparent object occured but is only supported since
+        // transparent object occurred but is only supported since
         // PDF 1.4
         Warning_Transparency_Omitted_PDF13,
 
@@ -590,7 +590,7 @@ The following structure describes the pe
         bool                            DisplayPDFDocumentTitle;
         PDFPageLayout                   PageLayout;
         bool                            FirstPageLeft;
-        // intially visible page in viewer (starting with 0 for first page)
+        // initially visible page in viewer (starting with 0 for first page)
         sal_Int32                       InitialPage;
         sal_Int32                       OpenBookmarkLevels; // -1 means all levels
 
@@ -687,9 +687,9 @@ The following structure describes the pe
     bool Emit();
 
     /*
-     * Get a list of errors that occured during processing
+     * Get a list of errors that occurred during processing
      * this should enable the producer to give feedback about
-     * any anomalies that might have occured
+     * any anomalies that might have occurred
      */
     std::set< ErrorCode > GetErrors();
 
@@ -1129,7 +1129,7 @@ The following structure describes the pe
     </p>
 
     <p>
-    Note: there is always one structural element in existance without having
+    Note: there is always one structural element in existence without having
     called <code>BeginStructureElement</code>; this is the root of the structure
     tree (called StructTreeRoot). The StructTreeRoot has always the id 0.
     </p>

Modified: openoffice/trunk/main/vcl/inc/vcl/ppdparser.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/ppdparser.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/ppdparser.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/ppdparser.hxx Tue Apr 29 19:25:03 2014
@@ -301,7 +301,7 @@ class VCL_DLLPUBLIC PPDContext
     const PPDParser*                                    m_pParser;
 
     // returns false: check failed, new value is constrained
-    //         true:  check succeded, new value can be set
+    //         true:  check succeeded, new value can be set
     bool checkConstraints( const PPDKey*, const PPDValue*, bool bDoReset );
     bool resetValue( const PPDKey*, bool bDefaultable = false );
 public:

Modified: openoffice/trunk/main/vcl/inc/vcl/print.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/print.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/print.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/print.hxx Tue Apr 29 19:25:03 2014
@@ -202,7 +202,7 @@ public:
     
     // read printer options from configuration, parameter decides whether the set for
     // print "to printer" or "to file" should be read.
-    // returns true if config was read, false if an error occured
+    // returns true if config was read, false if an error occurred
     bool                        ReadFromConfig( bool bFile );
 };
 
@@ -564,7 +564,7 @@ class VCL_DLLPUBLIC PrinterOptionsHelper
     {}
 
     /* process a new set of properties
-     * merges changed properties and returns "true" if any occured
+     * merges changed properties and returns "true" if any occurred
      * if the optional output set is not NULL then the names of the changed properties are returned
     **/
     bool processProperties( const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& i_rNewProp,

Modified: openoffice/trunk/main/vcl/inc/vcl/printerinfomanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/printerinfomanager.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/printerinfomanager.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/printerinfomanager.hxx Tue Apr 29 19:25:03 2014
@@ -88,7 +88,7 @@ public:
         rtl::OUString       m_aComment;
     };
 protected:
-    // needed for checkPrintersChanged: files (not necessarily existant)
+    // needed for checkPrintersChanged: files (not necessarily existent)
     // and their last known modification time
     struct WatchFile
     {

Modified: openoffice/trunk/main/vcl/inc/vcl/salnativewidgets.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/salnativewidgets.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/salnativewidgets.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/salnativewidgets.hxx Tue Apr 29 19:25:03 2014
@@ -63,7 +63,7 @@ typedef sal_uInt32		ControlType;
 #define CTRL_EDITBOX_NOBORDER	31
 
 // Control that allows text entry
-// ( some systems distingish between single and multi line edit boxes )
+// ( some systems distinguish between single and multi line edit boxes )
 #define CTRL_MULTILINE_EDITBOX 32
 
 // Control that pops up a menu,

Modified: openoffice/trunk/main/vcl/inc/vcl/strhelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/strhelper.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/strhelper.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/strhelper.hxx Tue Apr 29 19:25:03 2014
@@ -44,7 +44,7 @@ int VCL_DLLPUBLIC GetCommandLineTokenCou
 
 String VCL_DLLPUBLIC WhitespaceToSpace( const String&, sal_Bool bProtect = sal_True );
 ByteString VCL_DLLPUBLIC WhitespaceToSpace( const ByteString&, sal_Bool bProtect = sal_True );
-// returns a string with multiple adjacent occurences of whitespace
+// returns a string with multiple adjacent occurrences of whitespace
 // converted to a single space. if bProtect is sal_True (nonzero), then
 // doublequote, singlequote and singleleftquote protect their respective
 // contents

Modified: openoffice/trunk/main/vcl/inc/vcl/window.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/window.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/window.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/window.hxx Tue Apr 29 19:25:03 2014
@@ -825,7 +825,7 @@ public:
     
     Currently only mouse events get this special treatment.
     
-    Use this sparingly, chances are if you want to use it you're wroking around
+    Use this sparingly, chances are if you want to use it you're working around
     the real problem.
     
     @param bCall

Modified: openoffice/trunk/main/vcl/inc/win/salgdi.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/win/salgdi.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/win/salgdi.h (original)
+++ openoffice/trunk/main/vcl/inc/win/salgdi.h Tue Apr 29 19:25:03 2014
@@ -260,7 +260,7 @@ private:
     bool tryDrawBitmapGdiPlus(const SalTwoRect& rTR, const SalBitmap& rSrcBitmap);
 
 public:
-    // public SalGraphics methods, the interface to teh independent vcl part
+    // public SalGraphics methods, the interface to the independent vcl part
 
     // get device resolution
     virtual void			GetResolution( sal_Int32& rDPIX, sal_Int32& rDPIY );
@@ -306,7 +306,7 @@ public:
     virtual bool			AddTempDevFont( ImplDevFontList*, const String& rFileURL, const String& rFontName );
     // CreateFontSubset: a method to get a subset of glyhps of a font
     // inside a new valid font file
-    // returns TRUE if creation of subset was successfull
+    // returns TRUE if creation of subset was successful
     // parameters: rToFile: contains a osl file URL to write the subset to
     //             pFont: describes from which font to create a subset
     //             pGlyphIDs: the glyph ids to be extracted

Modified: openoffice/trunk/main/vcl/os2/source/app/salinst.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/os2/source/app/salinst.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/os2/source/app/salinst.cxx (original)
+++ openoffice/trunk/main/vcl/os2/source/app/salinst.cxx Tue Apr 29 19:25:03 2014
@@ -639,7 +639,7 @@ MRESULT EXPENTRY SalComWndProc( HWND hWn
 			ImplSalYield( (bool)nMP1, (bool) nMP2);
 			return 0;
         // If we get this message, because another GetMessage() call
-        // has recieved this message, we must post this message to
+        // has received this message, we must post this message to
         // us again, because in the other case we wait forever.
         case SAL_MSG_RELEASEWAITYIELD:
             {

Modified: openoffice/trunk/main/vcl/os2/source/app/saltimer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/os2/source/app/saltimer.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/os2/source/app/saltimer.cxx (original)
+++ openoffice/trunk/main/vcl/os2/source/app/saltimer.cxx Tue Apr 29 19:25:03 2014
@@ -109,7 +109,7 @@ void SalTimerProc( HWND, UINT, UINT nId,
 	bool bRecursive = pSalData->mbInTimerProc && (nId != SALTIMERPROC_RECURSIVE);
 	if ( pSVData->mpSalTimer && ! bRecursive )
 	{
-		// Try to aquire the mutex. If we don't get the mutex then we
+		// Try to acquire the mutex. If we don't get the mutex then we
 		// try this a short time later again.
 		if ( ImplSalYieldMutexTryToAcquire() )
 		{

Modified: openoffice/trunk/main/vcl/os2/source/gdi/salgdi2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/os2/source/gdi/salgdi2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/os2/source/gdi/salgdi2.cxx (original)
+++ openoffice/trunk/main/vcl/os2/source/gdi/salgdi2.cxx Tue Apr 29 19:25:03 2014
@@ -617,7 +617,7 @@ SalBitmap* Os2SalGraphics::getBitmap( lo
 	HBITMAP 		hMemBmp = ImplCreateVirDevBitmap( hMemDC, hMemPS, nDX, nDY, 0 );
 	HBITMAP 		hMemOld = Ft2SetBitmap( hMemPS, hMemBmp );
 
-	// creation successfull?
+	// creation successful?
 	if( hMemDC && hMemPS && hMemBmp )
 	{
 		POINTL thePoints[ 3 ];

Modified: openoffice/trunk/main/vcl/qa/complex/memCheck/CheckMemoryUsage.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/qa/complex/memCheck/CheckMemoryUsage.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/qa/complex/memCheck/CheckMemoryUsage.java (original)
+++ openoffice/trunk/main/vcl/qa/complex/memCheck/CheckMemoryUsage.java Tue Apr 29 19:25:03 2014
@@ -57,7 +57,7 @@ import static org.junit.Assert.*;
  * command line tool 'pmap', available on Solaris or Linux. This test will not
  * run on Windows.<br>Test procedure: every given document type is searched in 
  * the source directory 
- * Needed paramters:
+ * Needed parameters:
  * <ul>
  *   <li>"TestDocumentPath" - the path where test documents are located.</li>
  *   <li>"AllowMemoryIncrease" (optional) - the allowed memory increase measured in kByte per exported document. The default is 10 kByte.</li>

Modified: openoffice/trunk/main/vcl/source/app/dbggui.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/app/dbggui.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/app/dbggui.cxx (original)
+++ openoffice/trunk/main/vcl/source/app/dbggui.cxx Tue Apr 29 19:25:03 2014
@@ -94,13 +94,13 @@ static const sal_Char* pDbgHelpText[] =
 "\n",
 "DBG_CHKTHIS( aName, fTest )\n",
 "Can be used in methods of the class when constructors and the "
-"desctructor of the class are equiped with the corresponding macros. "
+"desctructor of the class are equipped with the corresponding macros. "
 "The first parameter is the registered name, the second parameter is "
 "the test function or 0.\n",
 "\n",
 "DBG_CHKOBJ( pObj, aName, fTest )\n",
 "Can be used on instances of a class where the constructors and the "
-"destructor of the class are equiped with the corresponding macros. "
+"destructor of the class are equipped with the corresponding macros. "
 "The first parameter is the registered name, the second parameter is "
 "the test function or 0.\n",
 "\n",
@@ -108,11 +108,11 @@ static const sal_Char* pDbgHelpText[] =
 "\n",
 "--- Options ---\n",
 "This\n",
-"The This pointer is validated. This way all objects that are equiped "
+"The This pointer is validated. This way all objects that are equipped "
 "with it can be tested to make sure one is working with existing objects. "
-"This way it's easier to find bugs in case of multiple inheritence, "
+"This way it's easier to find bugs in case of multiple inheritance, "
 "alignment or compiler errors. Since almost all standard classes of SV "
-"(String, List, Pen, Brush, Polygon, ...) are equiped with DBG_CHKTHIS() "
+"(String, List, Pen, Brush, Polygon, ...) are equipped with DBG_CHKTHIS() "
 "a lot of errors are found, although this test will impact performance "
 "accordingly.\n",
 "\n",
@@ -131,7 +131,7 @@ static const sal_Char* pDbgHelpText[] =
 " account. Therefor each SV program leaves 2 strings and a bitmap behind.\n",
 "\n",
 "Trace\n",
-"Creation, destruction and usage of objects which are equiped with "
+"Creation, destruction and usage of objects which are equipped with "
 "DBG_XTOR is logged.\n",
 "\n",
 "\n",
@@ -151,7 +151,7 @@ static const sal_Char* pDbgHelpText[] =
 "Allocated memory is initialized with 0x77 and free or freed memory "
 "is initialized with 0x33. This option has almost no impact on performance "
 "and should thus always be enabled during development. This will also "
-"make crashes more often reproducable.\n",
+"make crashes more often reproducible.\n",
 "\n",
 "Overwrite\n",
 "This test check whether writes occur before or after the blocks. Before "
@@ -195,14 +195,14 @@ static const sal_Char* pDbgHelpText[] =
 "Memory tests are performed on the entire memory with every new/delet. "
 "Warning: this option makes programs very slow and should only be enabled "
 "to track memory overwrites. Otherwise it is sufficient to enable "
-"seperate options because (if no leak is present) every detectable "
+"separate options because (if no leak is present) every detectable "
 "memory overwrite during run time should be found.\n",
 "\n",
 "Object Test\n",
 "Memory test are performed on the entire memory with every object test. "
 "Warning: this option makes programs very slow and should only be enabled "
 "to track memory overwrite. Otherwise it is sufficient to enable "
-"seperate options because (if no leak is present) every detectable "
+"separate options because (if no leak is present) every detectable "
 "memory overwrite during run time should be found.\n",
 "\n",
 "Windows 16-bit and debug tests\n",
@@ -232,7 +232,7 @@ static const sal_Char* pDbgHelpText[] =
 "exception handler is called.\n",
 "\n",
 "Dialog\n",
-"FixedTexts, CheckBoxes, TriStateBoxes and RadioButtons are equiped with "
+"FixedTexts, CheckBoxes, TriStateBoxes and RadioButtons are equipped with "
 "a different background color to determine the size of the controls. This "
 "test also shows whether controls overlap, whether the tab order is correct "
 "and whether the mnemonic characters are correctly assigned. With dialogs "
@@ -287,32 +287,32 @@ static const sal_Char* pDbgHelpText[] =
 "\n",
 "Include ObjectTest filters\n",
 "Only classes which contain one of the indicated filters are evaluated with "
-"the object test. Filters are seperated by ';' and are case sensitive. "
+"the object test. Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. If no text is indicated the filters are not "
 "active.\n",
 "\n",
 "Exclude ObjectTest filters\n",
 "Only classes which do not contain one of the indicated filters are evaluated "
-"with the object test. Filters are seperated by ';' and are case sensitive. "
+"with the object test. Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. If no text is indicated the filters are not "
 "active.\n",
 "\n",
 "Include filters\n",
 "Only those texts which include the indicated filters are output. "
-"Filters are seperated by ';' and are case sensitive. "
+"Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. The filter is used for all output (except for "
 "errors). If no text is indicated the filters are not active.\n",
 "\n",
 "Exclude filters\n",
 "Only those texts which do not include the indicated filters are output. "
-"Filters are seperated by ';' and are case sensitive. "
+"Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. The filter is used for all output (except for "
 "errors). If no text is indicated the filters are not active.\n",
 "\n",
 "Furthermore you can indicate where the data will be output:\n",
 "\n",
 "None\n",
-"Output is surpressed.\n",
+"Output is suppressed.\n",
 "\n",
 "File\n",
 "Outputi n debug file. Filename can be entered in the Editfield.\n",

Modified: openoffice/trunk/main/vcl/source/app/salvtables.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/app/salvtables.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/app/salvtables.cxx (original)
+++ openoffice/trunk/main/vcl/source/app/salvtables.cxx Tue Apr 29 19:25:03 2014
@@ -36,7 +36,7 @@
 #include <salmenu.hxx>
 
 // this file contains the virtual destructors of the sal interface
-// compilers ususally put their vtables where the destructor is
+// compilers usually put their vtables where the destructor is
 
 SalFrame::~SalFrame()
 {

Modified: openoffice/trunk/main/vcl/source/app/svapp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/app/svapp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/app/svapp.cxx (original)
+++ openoffice/trunk/main/vcl/source/app/svapp.cxx Tue Apr 29 19:25:03 2014
@@ -1755,7 +1755,7 @@ UnoWrapperBase* Application::GetUnoWrapp
 void Application::SetUnoWrapper( UnoWrapperBase* pWrapper )
 {
     ImplSVData* pSVData = ImplGetSVData();
-    DBG_ASSERT( !pSVData->mpUnoWrapper, "SetUnoWrapper: Wrapper allready exists" );
+    DBG_ASSERT( !pSVData->mpUnoWrapper, "SetUnoWrapper: Wrapper already exists" );
     pSVData->mpUnoWrapper = pWrapper;
 }
 

Modified: openoffice/trunk/main/vcl/source/app/svdata.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/app/svdata.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/app/svdata.cxx (original)
+++ openoffice/trunk/main/vcl/source/app/svdata.cxx Tue Apr 29 19:25:03 2014
@@ -213,7 +213,7 @@ Window* ImplGetDefaultWindow()
 
 	// First test if we already have a default window.
 	// Don't only place a single if..else inside solar mutex lockframe
-	// because then we might have to wait for the solar mutex what is not neccessary 
+	// because then we might have to wait for the solar mutex what is not necessary 
 	// if we already have a default window.
 
     if ( !pSVData->mpDefaultWin )

Modified: openoffice/trunk/main/vcl/source/app/svmain.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/app/svmain.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/app/svmain.cxx (original)
+++ openoffice/trunk/main/vcl/source/app/svmain.cxx Tue Apr 29 19:25:03 2014
@@ -632,7 +632,7 @@ void CreateMainLoopThread( oslWorkerFunc
         0,          // stacksize 0 means default
         _threadmain,    // thread worker function
         new WorkerThreadData( pWorker, pThreadData ),       // arguments for worker function
-        0,          // 0 means: create immediatly otherwise use CREATE_SUSPENDED
+        0,          // 0 means: create immediately otherwise use CREATE_SUSPENDED
         &uThreadID );   // thread id to fill
 #else
     hThreadID = osl_createThread( MainWorkerFunction, new WorkerThreadData( pWorker, pThreadData ) );

Modified: openoffice/trunk/main/vcl/source/control/button.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/control/button.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/control/button.cxx (original)
+++ openoffice/trunk/main/vcl/source/control/button.cxx Tue Apr 29 19:25:03 2014
@@ -514,7 +514,7 @@ void Button::ImplDrawAlignedImage( Outpu
         aMax.Width() = aTSSize.Width() > aImageSize.Width() ? aTSSize.Width() : aImageSize.Width();
         aMax.Height() = aTSSize.Height() > aImageSize.Height() ? aTSSize.Height() : aImageSize.Height();
 
-        // Now calculate the output area for the image and the text acording to the image align flags
+        // Now calculate the output area for the image and the text according to the image align flags
 
         if ( ( eImageAlign == IMAGEALIGN_LEFT ) ||
              ( eImageAlign == IMAGEALIGN_RIGHT ) )

Modified: openoffice/trunk/main/vcl/source/control/ilstbox.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/control/ilstbox.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/control/ilstbox.cxx (original)
+++ openoffice/trunk/main/vcl/source/control/ilstbox.cxx Tue Apr 29 19:25:03 2014
@@ -230,8 +230,8 @@ sal_uInt16 ImplEntryList::InsertEntry( s
 		}
 		catch (uno::RuntimeException& )
 		{
-			// XXX this is arguable, if the exception occured because pNewEntry is
-			// garbage you wouldn't insert it. If the exception occured because the
+			// XXX this is arguable, if the exception occurred because pNewEntry is
+			// garbage you wouldn't insert it. If the exception occurred because the
 			// Collator implementation is garbage then give the user a chance to see
 			// his stuff
 			Insert( pNewEntry, (sal_uLong)0 );
@@ -745,7 +745,7 @@ void ImplListBoxWindow::ImplCallSelect()
 {
 	if ( !IsTravelSelect() && GetEntryList()->GetMaxMRUCount() )
 	{
-		// Insert the selected entry as MRU, if not allready first MRU
+		// Insert the selected entry as MRU, if not already first MRU
 		sal_uInt16 nSelected = GetEntryList()->GetSelectEntryPos( 0 );
 		sal_uInt16 nMRUCount = GetEntryList()->GetMRUCount();
 		String aSelected = GetEntryList()->GetEntryText( nSelected );

Modified: openoffice/trunk/main/vcl/source/fontsubset/sft.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/fontsubset/sft.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/fontsubset/sft.cxx (original)
+++ openoffice/trunk/main/vcl/source/fontsubset/sft.cxx Tue Apr 29 19:25:03 2014
@@ -1179,7 +1179,7 @@ static void GetNames(TrueTypeFont *t)
     
     /* #i60349# sanity check psname
      * psname parctically has to be 7bit ascii and should not contains spaces
-     * there is a class of broken fonts which do not fullfill that at all, so let's try
+     * there is a class of broken fonts which do not fulfill that at all, so let's try
      * if the family name is 7bit ascii and take it instead if so
      */
     /* check psname */

Modified: openoffice/trunk/main/vcl/source/gdi/bitmapex.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/bitmapex.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/bitmapex.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/bitmapex.cxx Tue Apr 29 19:25:03 2014
@@ -994,7 +994,7 @@ BitmapEx BitmapEx::getTransformed(
     // aOutlineRange
     aTransform = rTransformation * aTransform;
     
-    // substract top-left of absolute VisibleRange
+    // subtract top-left of absolute VisibleRange
     aTransform.translate(
         -aVisibleRange.getMinX(), 
         -aVisibleRange.getMinY());

Modified: openoffice/trunk/main/vcl/source/gdi/cvtsvm.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/cvtsvm.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/cvtsvm.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/cvtsvm.cxx Tue Apr 29 19:25:03 2014
@@ -1376,7 +1376,7 @@ void SVMConverter::ImplConvertFromSVM1( 
 			}
                 }
 
-		// cleanup push-pop stack if neccessary
+		// cleanup push-pop stack if necessary
 		for( void* pLineInfo = aLIStack.Pop(); pLineInfo; pLineInfo = aLIStack.Pop() )
 			delete (LineInfo*) pLineInfo;
 
@@ -1421,7 +1421,7 @@ void SVMConverter::ImplConvertToSVM1( Sv
 	rOStm.Seek( nActPos );
 	rOStm.SetNumberFormatInt( nOldFormat );
 
-	// cleanup push-pop stack if neccessary
+	// cleanup push-pop stack if necessary
 	for( void* pCol = aLineColStack.Pop(); pCol; pCol = aLineColStack.Pop() )
 		delete (Color*) pCol;
 }

Modified: openoffice/trunk/main/vcl/source/gdi/gdimtf.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/gdimtf.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/gdimtf.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/gdimtf.cxx Tue Apr 29 19:25:03 2014
@@ -3095,7 +3095,7 @@ sal_Bool GDIMetaFile::CreateThumbnail( s
 		const_cast<GDIMetaFile *>(this)->WindStart();
 		const_cast<GDIMetaFile *>(this)->Play( &aVDev, aBackPosPix, aDrawSize );
 
-		// draw overlay if neccessary
+		// draw overlay if necessary
 		if ( pOverlay )
 			aVDev.DrawBitmapEx( aOverlayRect.TopLeft(), aOverlayRect.GetSize(), *pOverlay );
 

Modified: openoffice/trunk/main/vcl/source/gdi/outdev4.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/outdev4.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/outdev4.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/outdev4.cxx Tue Apr 29 19:25:03 2014
@@ -754,7 +754,7 @@ void OutputDevice::DrawGradient( const R
 			
 			mbInitFillColor = sal_True;
 
-			// calculate step count if neccessary
+			// calculate step count if necessary
 			if ( !aGradient.GetSteps() )
 				aGradient.SetSteps( GRADIENT_DEFAULT_STEPCOUNT );
 
@@ -919,7 +919,7 @@ void OutputDevice::DrawGradient( const P
 						
 						mbInitFillColor = sal_True;
 
-						// calculate step count if neccessary
+						// calculate step count if necessary
 						if ( !aGradient.GetSteps() )
 							aGradient.SetSteps( GRADIENT_DEFAULT_STEPCOUNT );
 
@@ -1028,7 +1028,7 @@ void OutputDevice::AddGradientActions( c
         aRect.Right()++;
         aRect.Bottom()++;
 
-		// calculate step count if neccessary
+		// calculate step count if necessary
 		if ( !aGradient.GetSteps() )
 			aGradient.SetSteps( GRADIENT_DEFAULT_STEPCOUNT );
 

Modified: openoffice/trunk/main/vcl/source/gdi/outdev6.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/outdev6.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/outdev6.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/outdev6.cxx Tue Apr 29 19:25:03 2014
@@ -241,7 +241,7 @@ void OutputDevice::DrawTransparent( cons
 		return;
 	}
 
-	// short circut for drawing an invisible polygon
+	// short circuit for drawing an invisible polygon
 	if( !mbFillColor || (nTransparencePercent >= 100) )
 	{
 		// short circuit if the polygon border is invisible too
@@ -682,7 +682,7 @@ void OutputDevice::DrawTransparent( cons
 				if(GetAntialiasing())
 				{
 					// #i102109#
-					// For MetaFile replay (see task) it may now be neccessary to take
+					// For MetaFile replay (see task) it may now be necessary to take
 					// into account that the content is AntiAlialised and needs to be masked
 					// like that. Instead of masking, i will use a copy-modify-paste cycle
 					// here (as i already use in the VclPrimiziveRenderer with successs)

Modified: openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.cxx Tue Apr 29 19:25:03 2014
@@ -4302,7 +4302,7 @@ bool PDFWriterImpl::emitFonts()
         if( ((++ni) & 7) == 0 )
             aFontDict.append( '\n' );
     }
-    // emit builtin font for widget apperances / variable text
+    // emit builtin font for widget appearances / variable text
     for( std::map< sal_Int32, sal_Int32 >::iterator it = m_aBuiltinFontToObjectMap.begin();
         it != m_aBuiltinFontToObjectMap.end(); ++it )
     {
@@ -4731,7 +4731,7 @@ we check in the following sequence:
 				}
 				else
 				{
-// change the fragment to accomodate the bookmark (only if the file extension is PDF and
+// change the fragment to accommodate the bookmark (only if the file extension is PDF and
 // the requested action is of the correct type)
 					if(m_aContext.DefaultLinkAction == PDFWriter::URIActionDestination &&
 							   bTargetHasPDFExtension && aFragment.getLength() > 0 )
@@ -6157,7 +6157,7 @@ sal_Int32 PDFWriterImpl::emitNamedDestin
             aLine.append( '/' );
             appendDestinationName( aName, aLine ); // this conversion must be done when forming the link to target ( see in emitCatalog )
             aLine.append( '[' ); // the '[' can be emitted immediately, because the appendDestinationName function
-                                 //maps the preceeding character properly
+                                 //maps the preceding character properly
             aLine.append( rDestPage.m_nPageObject );
             aLine.append( " 0 R" );
 

Modified: openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.hxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl.hxx Tue Apr 29 19:25:03 2014
@@ -964,7 +964,7 @@ i12626 
     sal_Int32 updateOutlineItemCount( std::vector< sal_Int32 >& rCounts,
                                       sal_Int32 nItemLevel,
                                       sal_Int32 nCurrentItemId );
-    // default appearences for widgets
+    // default appearances for widgets
     sal_Int32 findRadioGroupWidget( const PDFWriter::RadioButtonWidget& rRadio );
     Font replaceFont( const Font& rControlFont, const Font& rAppSetFont );
     sal_Int32 getBestBuiltinFont( const Font& rFont );

Modified: openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl2.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/pdfwriter_impl2.cxx Tue Apr 29 19:25:03 2014
@@ -104,7 +104,7 @@ void PDFWriterImpl::implWriteBitmapEx( c
         }
 		if( i_rContext.m_nMaxImageResolution > 50 )
 		{
-			// do downsampling if neccessary
+			// do downsampling if necessary
 			const Size      aDstSizeTwip( i_pDummyVDev->PixelToLogic( i_pDummyVDev->LogicToPixel( aSize ), MAP_TWIP ) );
 			const Size      aBmpSize( aBitmapEx.GetSizePixel() );
 			const double    fBmpPixelX = aBmpSize.Width();
@@ -168,7 +168,7 @@ void PDFWriterImpl::implWriteBitmapEx( c
 			if ( bUseJPGCompression )
 			{
 				sal_uInt32 nZippedFileSize;		// sj: we will calculate the filesize of a zipped bitmap
-				{								// to determine if jpeg compression is usefull
+				{								// to determine if jpeg compression is useful
 					SvMemoryStream aTemp;
 					aTemp.SetCompressMode( aTemp.GetCompressMode() | COMPRESSMODE_ZBITMAP );
 					aTemp.SetVersion( SOFFICE_FILEFORMAT_40 );	// sj: up from version 40 our bitmap stream operator
@@ -1176,7 +1176,7 @@ void PDFWriterImpl::checkAndEnableStream
         // the i+2 to take into account the generation number, always zero
         rtl_digest_MD5( &m_aContext.Encryption.EncryptionKey[0], i+2, nMD5Sum, sizeof(nMD5Sum) );
         // initialize the RC4 with the key
-        // key legth: see algoritm 3.1, step 4: (N+5) max 16
+        // key legth: see algorithm 3.1, step 4: (N+5) max 16
         rtl_cipher_initARCFOUR( m_aCipher, rtl_Cipher_DirectionEncode, nMD5Sum, m_nRC4KeyLength, NULL, 0 );
     }
 }
@@ -1195,7 +1195,7 @@ void PDFWriterImpl::enableStringEncrypti
         // the i+2 to take into account the generation number, always zero
         rtl_digest_MD5( &m_aContext.Encryption.EncryptionKey[0], i+2, nMD5Sum, sizeof(nMD5Sum) );
         // initialize the RC4 with the key
-        // key legth: see algoritm 3.1, step 4: (N+5) max 16
+        // key legth: see algorithm 3.1, step 4: (N+5) max 16
         rtl_cipher_initARCFOUR( m_aCipher, rtl_Cipher_DirectionEncode, nMD5Sum, m_nRC4KeyLength, NULL, 0 );
     }
 }
@@ -1520,7 +1520,7 @@ bool PDFWriterImpl::computeUDictionaryVa
             else
             {
                 //or 3.5, for 128 bit security
-                //step6, initilize the last 16 bytes of the encrypted user password to 0
+                //step6, initialize the last 16 bytes of the encrypted user password to 0
                 for(sal_uInt32 i = MD5_DIGEST_SIZE; i < sal_uInt32(io_rProperties.UValue.size()); i++)
                     io_rProperties.UValue[i] = 0;
                 //step 2

Modified: openoffice/trunk/main/vcl/source/gdi/pngread.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/pngread.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/pngread.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/pngread.cxx Tue Apr 29 19:25:03 2014
@@ -117,7 +117,7 @@ private:
     sal_Int32           mnChunkLen;     // Length of current PNG chunk
     Size                maOrigSize;     // pixel size of the full image
     Size                maTargetSize;   // pixel size of the result image
-    Size                maPhysSize;     // prefered size in MAP_100TH_MM units
+    Size                maPhysSize;     // preferred size in MAP_100TH_MM units
     sal_uInt32          mnBPP;          // number of bytes per pixel
     sal_uInt32          mnScansize;     // max size of scanline
     sal_uInt32          mnYpos;         // latest y position in full image

Modified: openoffice/trunk/main/vcl/source/gdi/print.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/print.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/print.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/print.cxx Tue Apr 29 19:25:03 2014
@@ -156,7 +156,7 @@ bool PrinterOptions::ReadFromConfig( boo
     {
         // get service provider
         Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
-        // create configuration hierachical access name
+        // create configuration hierarchical access name
         if( xSMgr.is() )
         {
             try
@@ -568,7 +568,7 @@ SalPrinterQueueInfo* Printer::ImplGetQue
 	ImplPrnQueueList* pPrnList = pSVData->maGDIData.mpPrinterQueueList;
 	if ( pPrnList && pPrnList->m_aQueueInfos.size() )
 	{
-		// first search for the printer name driectly
+		// first search for the printer name directly
 		ImplPrnQueueData* pInfo = pPrnList->Get( rPrinterName );
 		if( pInfo )
 			return pInfo->mpSalQueueInfo;

Modified: openoffice/trunk/main/vcl/source/gdi/print2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/print2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/print2.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/print2.cxx Tue Apr 29 19:25:03 2014
@@ -1380,7 +1380,7 @@ Bitmap OutputDevice::GetDownsampledBitma
         const Rectangle aBmpRect( aPoint, aBmp.GetSizePixel() );
         Rectangle       aSrcRect( rSrcPt, rSrcSz );
 
-        // do cropping if neccessary
+        // do cropping if necessary
         if( aSrcRect.Intersection( aBmpRect ) != aBmpRect )
         {
             if( !aSrcRect.IsEmpty() )
@@ -1391,7 +1391,7 @@ Bitmap OutputDevice::GetDownsampledBitma
 
         if( !aBmp.IsEmpty() )
         {
-            // do downsampling if neccessary
+            // do downsampling if necessary
             Size aDstSizeTwip( PixelToLogic( LogicToPixel( rDstSz ), MAP_TWIP ) );
 
             // #103209# Normalize size (mirroring has to happen outside of this method)
@@ -1449,7 +1449,7 @@ BitmapEx OutputDevice::GetDownsampledBit
         const Rectangle aBmpRect( aPoint, aBmpEx.GetSizePixel() );
         Rectangle       aSrcRect( rSrcPt, rSrcSz );
 
-        // do cropping if neccessary
+        // do cropping if necessary
         if( aSrcRect.Intersection( aBmpRect ) != aBmpRect )
         {
             if( !aSrcRect.IsEmpty() )
@@ -1460,7 +1460,7 @@ BitmapEx OutputDevice::GetDownsampledBit
 
         if( !aBmpEx.IsEmpty() )
         {
-            // do downsampling if neccessary
+            // do downsampling if necessary
             Size aDstSizeTwip( PixelToLogic( LogicToPixel( rDstSz ), MAP_TWIP ) );
 
             // #103209# Normalize size (mirroring has to happen outside of this method)

Modified: openoffice/trunk/main/vcl/source/gdi/print3.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/print3.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/print3.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/print3.cxx Tue Apr 29 19:25:03 2014
@@ -1217,7 +1217,7 @@ void PrinterController::printFilteredPag
         mpImplData->mpPrinter->SetPaperBin( mpImplData->mnFixedPaperBin );
     }
 
-    // if full paper is meant to be used, move the output to accomodate for pageoffset
+    // if full paper is meant to be used, move the output to accommodate for pageoffset
     if( aPageSize.bFullPaper )
     {
         Point aPageOffset( mpImplData->mpPrinter->GetPageOffset() );

Modified: openoffice/trunk/main/vcl/source/gdi/regband.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/regband.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/regband.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/regband.cxx Tue Apr 29 19:25:03 2014
@@ -187,7 +187,7 @@ void ImplRegionBand::ProcessPoints()
 
 		ImplRegionBandPoint* pNextBandPoint = pRegionBandPoint->mpNextBandPoint->mpNextBandPoint;
 
-		// remove allready processed points
+		// remove already processed points
 		delete pRegionBandPoint->mpNextBandPoint;
 		delete pRegionBandPoint;
 
@@ -222,7 +222,7 @@ bool ImplRegionBand::InsertPoint( long n
 		return true;
 	}
 
-	// look if line allready touched the band
+	// look if line already touched the band
 	ImplRegionBandPoint* pRegionBandPoint = mpFirstBandPoint;
 	ImplRegionBandPoint* pLastTestedRegionBandPoint = NULL;
 	while( pRegionBandPoint )
@@ -932,7 +932,7 @@ bool ImplRegionBand::operator==( const I
 		pSecondRectBandSep = pSecondRectBandSep->mpNextSep;
 	}
 
-	// differnt number of separations?
+	// different number of separations?
 	if ( pOwnRectBandSep || pSecondRectBandSep )
 		return false;
--- openoffice/trunk/main/uui/source/fltdlg.cxx (original)
+++ openoffice/trunk/main/uui/source/fltdlg.cxx Tue Apr 29 19:25:03 2014
@@ -55,7 +55,7 @@ namespace uui
 
 /*-************************************************************************************************************//**
     @short      initialize filter dialog with start values
-    @descr      We set some neccessary informations on these instance for later working and create internal structures.
+    @descr      We set some necessary informations on these instance for later working and create internal structures.
                 After construction user should call "SetFilters()" and "SetURL()" to fill listbox with selectable filter
                 names and set file name of file, which should be used for selected filter.
 
@@ -95,7 +95,7 @@ FilterDialog::FilterDialog( Window* pPar
 *//*-*************************************************************************************************************/
 void FilterDialog::SetURL( const String& sURL )
 {
-    // convert it and use given pure string as fallback if convertion failed
+    // convert it and use given pure string as fallback if conversion failed
     m_ftURL.SetText( impl_buildUIFileName(sURL) );
 }
 
@@ -137,8 +137,8 @@ void FilterDialog::ChangeFilters( const 
     @short      ask user for his decision
     @descr      We show the dialog and if user finish it with "OK" - we try to find selected item in internal saved
                 name list (which you must set in "ChangeFilters()"!). If we return sal_True as result, you can use out
-                parameter "pSelectedItem" as pointer into your FilterNameList to get selected item realy ...
-                but if we return sal_False ... user hsa cancel the dialog ... you shouldnt do that. pSelectedItem isnt
+                parameter "pSelectedItem" as pointer into your FilterNameList to get selected item really ...
+                but if we return sal_False ... user hsa cancel the dialog ... you shouldn't do that. pSelectedItem isn't
                 set to any valid value then. We don't change them ...
 
     @seealso    method ChangeFilters()
@@ -146,7 +146,7 @@ void FilterDialog::ChangeFilters( const 
     @param      "pSelectedItem", returns result of selection as pointer into set list of filter names
                                  (valid for function return sal_True only!)
     @return     true  => pSelectedItem parameter points into name list and represent use decision
-                false => use has cancelled dialog (pSelectedItem isnt valid then!)
+                false => use has cancelled dialog (pSelectedItem isn't valid then!)
 
     @onerror    We return false ... but don't change pSelectedItem!
     @threadsafe no
@@ -209,7 +209,7 @@ class StringCalculator : public ::cppu::
 
 /*-************************************************************************************************************//**
     @short      try to build short name of given URL to show it n GUI
-    @descr      We detect type of given URL automaticly and build this short name depend on this type ...
+    @descr      We detect type of given URL automatically and build this short name depend on this type ...
                 If we couldnt make it right we return full given string without any changes ...
 
     @seealso    class LocalFileHelper
@@ -231,7 +231,7 @@ String FilterDialog::impl_buildUIFileNam
     }
     else
     {
         // otherwise its realy a url ... build short name by using INetURLObject
         ::com::sun::star::uno::Reference< ::com::sun::star::util::XStringWidth > xStringCalculator( new StringCalculator(&m_ftURL) );
         if( xStringCalculator.is() == sal_True )
         {
@@ -231,7 +231,7 @@ String FilterDialog::impl_buildUIFileNam
     else
     {
-        // otherwise its realy a url ... build short name by using INetURLObject
+        // otherwise its really a url ... build short name by using INetURLObject
         ::com::sun::star::uno::Reference< ::com::sun::star::util::XStringWidth > xStringCalculator( new StringCalculator(&m_ftURL) );
         if( xStringCalculator.is() == sal_True )

Modified: openoffice/trunk/main/uui/source/iahndl-filter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/uui/source/iahndl-filter.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================